Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(186)

Unified Diff: client/crashpad_info.h

Issue 1126413008: win: Implement exception snapshot (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: fixes2 Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « client/crashpad_client_win.cc ('k') | client/crashpad_info.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/crashpad_info.h
diff --git a/client/crashpad_info.h b/client/crashpad_info.h
index 57ea4eb33af9e2613fbeb1b1c84fe9a95fe1b522..d9d239c442c4027bd5f5cb5bf657d908e93d4100 100644
--- a/client/crashpad_info.h
+++ b/client/crashpad_info.h
@@ -99,10 +99,15 @@ struct CrashpadInfo {
}
#if defined(OS_WIN)
- //! \brief Save an EXCEPTION_POINTERS record for the crash handler.
+ //! \brief Save the crashing thread ID for the crash handler.
+ void set_thread_id(DWORD thread_id) { thread_id_ = thread_id; }
+ DWORD thread_id() const { return thread_id_; }
+
+ //! \brief Save an `EXCEPTION_POINTERS` record for the crash handler.
void set_exception_pointers(EXCEPTION_POINTERS* exception_pointers) {
exception_pointers_ = exception_pointers;
}
+ EXCEPTION_POINTERS* exception_pointers() const { return exception_pointers_; }
#endif // OS_WIN
enum : uint32_t {
@@ -130,6 +135,7 @@ struct CrashpadInfo {
#if defined(OS_WIN)
EXCEPTION_POINTERS* exception_pointers_;
+ DWORD thread_id_;
#endif // OS_WIN
#if defined(__clang__)
« no previous file with comments | « client/crashpad_client_win.cc ('k') | client/crashpad_info.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698